@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl
 # $File: //member/autrijus/PAR/script/par.pl $ $Author: autrijus $
-# $Revision: #80 $ $Change: 8491 $ $DateTime: 2003/10/19 15:19:48 $ vim: expandtab shiftwidth=4
+# $Revision: #82 $ $Change: 9273 $ $DateTime: 2003/12/11 22:09:17 $ vim: expandtab shiftwidth=4
 
 package __par_pl;
 
@@ -386,23 +386,27 @@ if ($out) {
         die "$par is not a PAR file" unless <PAR> eq "PK\003\004";
     }
 
-    open OUT, '>', $out or die $!;
-    binmode(OUT);
+    require IO::File;
+    require Archive::Zip;
+    my $fh = IO::File->new(
+	$out,
+	IO::File::O_CREAT() | IO::File::O_WRONLY() | IO::File::O_TRUNC(),
+	0777,
+    ) or die $!;
+    binmode($fh);
 
     $/ = (defined $data_pos) ? \$data_pos : undef;
     seek _FH, 0, 0;
     my $loader = scalar <_FH>;
     if (!$ENV{PAR_VERBATIM} and $loader =~ /^(?:#!|\@rem)/) {
-        print OUT pod_strip($loader, $0);
-    }
-    else {
-        print OUT $loader;
+        require PAR::Filter::PodStrip;
+        PAR::Filter::PodStrip->new->apply(\$loader, $file)
     }
+    $fh->print($loader);
     $/ = undef;
     # }}}
 
     # Write bundled modules {{{
-    my $data_len = 0;
     if ($bundle) {
         require PAR::Heavy;
         PAR::Heavy::_init_dynaloader();
@@ -466,36 +470,31 @@ if ($out) {
                 $content = <FILE>;
                 close FILE;
 
-                $content = pod_strip($content, $file)
+                PAR::Filter::PodStrip->new->apply(\$content, $file)
                     if !$ENV{PAR_VERBATIM} and lc($name) =~ /\.(?:pm|ix|al)$/i;
             }
 
             outs(qq(Written as "$name"));
-            print OUT "FILE";
-            print OUT pack('N', length($name) + 9);
-            print OUT sprintf(
+            $fh->print("FILE");
+            $fh->print(pack('N', length($name) + 9));
+            $fh->print(sprintf(
                 "%08x/%s", Archive::Zip::computeCRC32($content), $name
-            );
-            print OUT pack('N', length($content));
-            print OUT $content;
-
-            $data_len += 12 + length($name) + 9 + length($content);
+            ));
+            $fh->print(pack('N', length($content)));
+            $fh->print($content);
         }
     }
     # }}}
 
     # Now write out the PAR and magic strings {{{
     if (defined($par)) {
-        print OUT "PK\003\004";
-        print OUT <PAR>;
-        print OUT pack('N', $data_len + (stat($par))[7]);
-    }
-    else {
-        print OUT pack('N', $data_len);
+        my $zip = Archive::Zip->new($par);
+        $zip->writeToFileHandle($fh);
     }
 
-    print OUT "\nPAR.pm\n";
-    close OUT;
+    $fh->print(pack('N', $fh->tell - length($loader)));
+    $fh->print("\nPAR.pm\n");
+    $fh->close;
     chmod 0755, $out;
     # }}}
 
@@ -576,6 +575,7 @@ sub require_modules {
     require PAR;
     require PAR::Heavy;
     require PAR::Dist;
+    require PAR::Filter::PodStrip;
 }
 
 # N.B. we set PAR_TMP_DIR and PAR_TEMP in myldr/main.c
@@ -631,38 +631,6 @@ sub _tempfile {
 
 sub outs { warn("@_\n") unless $quiet }
 
-sub pod_strip {
-    my ($pl_text, $filename) = @_;
-
-    local $^W;
-
-    my $data = '';
-    $data = $1 if $pl_text =~ s/((?:^__DATA__$).*)//ms;
-
-    my $line = 1;
-    if ($pl_text =~ /^=(?:head\d|pod|begin|item|over|for|back|end)\b/) {
-        $pl_text = "\n$pl_text";
-        $line--;
-    }
-    $pl_text =~ s{(
-	(.*?\n)
-	=(?:head\d|pod|begin|item|over|for|back|end)\b
-	.*?\n
-	(?:=cut[\t ]*[\r\n]*?|\Z)
-	(\r?\n)?
-    )}{
-	my ($pre, $post) = ($2, $3);
-        "$pre#line " . (
-	    $line += ( () = ( $1 =~ /\n/g ) )
-	) . $post;
-    }gsex;
-    $pl_text = '#line 1 "' . ($filename) . "\"\n" . $pl_text
-        if length $filename;
-    $pl_text =~ s/^#line 1 (.*\n)(#!.*\n)/$2#line 2 $1/g;
-
-    return $pl_text . $data;
-}
-
 sub init_inc {
     require Config;
     push @INC, grep defined, map $Config::Config{$_}, qw(
